@@ -7,8 +7,7 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef SELECTDEVICEANDFILESPAGE_H
-#define SELECTDEVICEANDFILESPAGE_H
+#pragma once
 
 #include "ui_selectfilediscover.h"
 
@@ -34,5 +33,3 @@ private Q_SLOTS:
 private:
     SendFileWizard *const m_wizard;
 };
-
-#endif // SELECTDEVICEANDFILESPAGE_H
